@@ -1,3 +1,4 @@
+import warnings
 from typing import Union
 
 from . import errors as err
@@ -45,11 +46,45 @@ class Model:
     def __init__(self, language, evaluator=None):
         self.evaluator = evaluator
         self.language = language
+        # self.vocabulary = language.vocabulary()
         self.function_extensions = dict()
         self.predicate_extensions = dict()
 
-    def setx(self, term: CompoundTerm, value: Constant):
+    def __eq__(self, other):
+        # TODO Improve the performance of this
+        return str(self) == str(other)
+
+    def __hash__(self):
+        # TODO Improve the performance of this
+        return hash(str(self))
+
+    # def __eq__(self, other):
+    #     return self.__class__ is other.__class__ and self._data() == other._data()
+    #
+    # def __hash__(self):
+    #     return hash(self._data())
+
+    # def _data(self):
+    #     preds, funcs, _ = self.vocabulary
+    #     components = (preds, funcs)
+    #     for p in preds:
+    #         extension = self.predicate_extensions.get(p, set())
+    #         components += tuple(frozenset(unwrap_to_name(x) for x in extension))
+    #
+    #     for f in funcs:
+    #         extension = self.function_extensions.get(f, ExtensionalFunctionDefinition())
+    #         components += tuple(frozenset(unwrap_to_name(point) + (str(value.expr), )
+    #                                       for point, value in extension.data.items()))
+    #     return components
+
+    def set(self, term: CompoundTerm, value: Union[Constant, int, float], *args):
         """ Set the value of the interpretation on the given term to be equal to `value`. """
+        if not isinstance(term, CompoundTerm):
+            warnings.warn('Usage of Model.set(function, *arguments) is deprecated. Use'
+                          'Model.set(term, value) instead', DeprecationWarning)
+            allargs = [value] + args
+            self.set(term(*allargs[:-1]), allargs[-1])
+
         if not isinstance(term.symbol, Function):
             raise err.SemanticError("Model.set() can only set the value of function symbols")
         if term.symbol.builtin:
@@ -64,11 +99,6 @@ class Model:
 
         definition.set(point, value)
 
-    def set(self, fun, *args):
-        """ Set the value of fun(args[:-1]) to be args[-1] for the current interpretation """
-        # TODO: Deprecate in favor of Model.setx()
-        self.setx(fun(*args[:-1]), args[-1])
-
     def add(self, predicate, *args):
         """ """
         from .syntax import Atom  # pylint: disable=import-outside-toplevel  # Avoiding circular references
@@ -85,8 +115,17 @@ class Model:
         definition.add(wrap_tuple(point))
 
     def remove(self, predicate: Predicate, *args):
+        """ Remove a given point from the extension of a predicate.
+        Raises exception if the extension does not contain the point. """
         self.predicate_extensions[predicate.signature].remove(wrap_tuple(args))
 
+    def discard(self, predicate: Predicate, *args):
+        """ Remove a given point from the extension of a predicate.
+        Does not raise any exception if the extension does not contain the point. """
+        ext = self.predicate_extensions.get(predicate.signature)
+        if ext is not None:
+            ext.discard(wrap_tuple(args))
+
     def value(self, fun: Function, point):
         """ Return the value of the given function on the given point in the current model """
         definition = self.function_extensions[fun.signature]
@@ -155,9 +194,7 @@ class Model:
             return self.evaluator(arg, self)
 
     def __str__(self):
-        npreds = len(self.predicate_extensions)
-        nfuns = len(self.function_extensions)
-        return f'Model(num_predicates="{npreds}", num_functions="{nfuns}")'
+        return f'Model[{", ".join(sorted(map(str, self.as_atoms())))}]'
     __repr__ = __str__
 
     def remove_symbol(self, symbol: Union[Function, Predicate]):
@@ -205,6 +242,10 @@ def unwrap_tuple(tup):
     return tuple(ref.expr for ref in tup)
 
 
+def unwrap_to_name(tup):
+    return tuple(ref.expr.name for ref in tup)
+
+
 class ModelWithoutEvaluatorError(err.SemanticError):
     def __init__(self, exp):
         super().__init__(f'Attempted to evaluate expression "{exp}" on a model with no attached evaluator. '
